==> ovito_3.10.5~ds.orig.tar.xz: ovito-v3.10.5/src/ovito/gui/desktop/app/GuiApplicationService.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2023 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/gui/desktop/GUI.h>
#include <ovito/core/app/ApplicationService.h>

namespace Ovito {

/**
 * \brief Abstract base class for plugin services that can perform actions on application startup.
 */
class OVITO_GUI_EXPORT GuiApplicationService : public ApplicationService
{
    OVITO_CLASS(GuiApplicationService)

public:

    /// \brief Is called when a new main window is created.
    virtual void registerActions(ActionManager& actionManager, MainWindow& mainWindow) {}

    /// \brief Is called when the main menu is created.
    virtual void addActionsToMenu(ActionManager& actionManager, QMenuBar* menuBar) {}
};

}   // End of namespace

==> ovito_3.13.1~ds.orig.tar.xz: ovito-v3.13.1/src/ovito/gui/desktop/app/GuiApplicationService.h <==
////////////////////////////////////////////////////////////////////////////////////////
//
//  Copyright 2025 OVITO GmbH, Germany
//
//  This file is part of OVITO (Open Visualization Tool).
//
//  OVITO is free software; you can redistribute it and/or modify it either under the
//  terms of the GNU General Public License version 3 as published by the Free Software
//  Foundation (the "GPL") or, at your option, under the terms of the MIT License.
//  If you do not alter this notice, a recipient may use your version of this
//  file under either the GPL or the MIT License.
//
//  You should have received a copy of the GPL along with this program in a
//  file LICENSE.GPL.txt.  You should have received a copy of the MIT License along
//  with this program in a file LICENSE.MIT.txt
//
//  This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND,
//  either express or implied. See the GPL or the MIT License for the specific language
//  governing rights and limitations.
//
////////////////////////////////////////////////////////////////////////////////////////

#pragma once


#include <ovito/gui/desktop/GUI.h>
#include <ovito/core/app/ApplicationService.h>

namespace Ovito {

/**
 * \brief Abstract base class for plugin services that integrate into the main window GUI.
 */
class OVITO_GUI_EXPORT GuiApplicationService : public ApplicationService
{
    OVITO_CLASS(GuiApplicationService)

public:

    /// Is called when a new main window is created.
    virtual void registerActions(ActionManager& actionManager, MainWindow& mainWindow) {}
};

}   // End of namespace
